FELIX-1116: remove some remaining references to servicemix

git-svn-id: https://svn.apache.org/repos/asf/felix/trunk@771229 13f79535-47bb-0310-9956-ffa450edef68
diff --git a/karaf/gshell/gshell-admin/pom.xml b/karaf/gshell/gshell-admin/pom.xml
index fd50615..36faa9d 100644
--- a/karaf/gshell/gshell-admin/pom.xml
+++ b/karaf/gshell/gshell-admin/pom.xml
@@ -43,11 +43,11 @@
             org.apache.geronimo.gshell*,
         </gshell.osgi.import>
         <gshell.osgi.export>
-            org.apache.servicemix.jpm
+            org.apache.felix.karaf.jpm
         </gshell.osgi.export>
         <gshell.osgi.private>
             org.apache.felix.karaf.gshell.admin.*,
-            org.apache.servicemix.jpm.impl
+            org.apache.feix.karaf.jpm.impl
         </gshell.osgi.private>
     </properties>
 
diff --git a/karaf/gshell/gshell-admin/src/main/filtered-resources/org/apache/felix/karaf/gshell/admin/etc/org.apache.servicemix.features.cfg b/karaf/gshell/gshell-admin/src/main/filtered-resources/org/apache/felix/karaf/gshell/admin/etc/org.apache.felix.karaf.features.cfg
similarity index 100%
rename from karaf/gshell/gshell-admin/src/main/filtered-resources/org/apache/felix/karaf/gshell/admin/etc/org.apache.servicemix.features.cfg
rename to karaf/gshell/gshell-admin/src/main/filtered-resources/org/apache/felix/karaf/gshell/admin/etc/org.apache.felix.karaf.features.cfg
diff --git a/karaf/gshell/gshell-admin/src/main/java/org/apache/felix/karaf/gshell/admin/internal/AdminServiceImpl.java b/karaf/gshell/gshell-admin/src/main/java/org/apache/felix/karaf/gshell/admin/internal/AdminServiceImpl.java
index 002c6c9..48d03b4 100644
--- a/karaf/gshell/gshell-admin/src/main/java/org/apache/felix/karaf/gshell/admin/internal/AdminServiceImpl.java
+++ b/karaf/gshell/gshell-admin/src/main/java/org/apache/felix/karaf/gshell/admin/internal/AdminServiceImpl.java
@@ -79,7 +79,7 @@
             }
             instances = newInstances;
         } catch (Exception e) {
-            LOGGER.warn("Unable to reload ServiceMix instance list", e);
+            LOGGER.warn("Unable to reload Karaf instance list", e);
         }
     }
 
@@ -117,7 +117,7 @@
         mkdir(serviceMixBase, "data");
 
         copyResourceToDir(serviceMixBase, "etc/config.properties", true);
-        copyResourceToDir(serviceMixBase, "etc/org.apache.servicemix.features.cfg", true);
+        copyResourceToDir(serviceMixBase, "etc/org.apache.felix.karaf.features.cfg", true);
         copyResourceToDir(serviceMixBase, "etc/users.properties", true);
         copyResourceToDir(serviceMixBase, "etc/org.ops4j.pax.logging.cfg", true);
         copyResourceToDir(serviceMixBase, "etc/org.ops4j.pax.url.mvn.cfg", true);
@@ -131,10 +131,10 @@
         copyFilteredResourceToDir(serviceMixBase, "etc/system.properties", props);
         copyFilteredResourceToDir(serviceMixBase, "etc/org.apache.felix.karaf.shell.cfg", props);
         if( System.getProperty("os.name").startsWith("Win") ) {
-            copyFilteredResourceToDir(serviceMixBase, "bin/servicemix.bat", props);
+            copyFilteredResourceToDir(serviceMixBase, "bin/karaf.bat", props);
         } else {
-            copyFilteredResourceToDir(serviceMixBase, "bin/servicemix", props);
-            chmod(new File(serviceMixBase, "bin/servicemix"), "a+x");
+            copyFilteredResourceToDir(serviceMixBase, "bin/karaf", props);
+            chmod(new File(serviceMixBase, "bin/karaf"), "a+x");
         }
         Instance instance = new InstanceImpl(this, name, serviceMixBase.toString());
         instances.put(name, instance);
diff --git a/karaf/gshell/gshell-admin/src/main/java/org/apache/felix/karaf/gshell/admin/internal/commands/DestroyCommand.java b/karaf/gshell/gshell-admin/src/main/java/org/apache/felix/karaf/gshell/admin/internal/commands/DestroyCommand.java
index 8f0235f..b41dd8c 100644
--- a/karaf/gshell/gshell-admin/src/main/java/org/apache/felix/karaf/gshell/admin/internal/commands/DestroyCommand.java
+++ b/karaf/gshell/gshell-admin/src/main/java/org/apache/felix/karaf/gshell/admin/internal/commands/DestroyCommand.java
@@ -19,13 +19,13 @@
 import org.apache.geronimo.gshell.clp.Argument;
 
 /**
- * Creates a new servicemix instance
+ * Destroy an existing Karaf instance
  *
  * @version $Rev: 679826 $ $Date: 2008-07-25 17:00:12 +0200 (Fri, 25 Jul 2008) $
  */
 public class DestroyCommand extends AdminCommandSupport
 {
-    @Argument(index=0, required=true, description="The name of the ServiceMix instance to destroy")
+    @Argument(index=0, required=true, description="The name of the Karaf instance to destroy")
     private String instance = null;
 
     protected Object doExecute() throws Exception {
diff --git a/karaf/gshell/gshell-admin/src/main/resources/org/apache/felix/karaf/gshell/admin/etc/org.ops4j.pax.logging.cfg b/karaf/gshell/gshell-admin/src/main/resources/org/apache/felix/karaf/gshell/admin/etc/org.ops4j.pax.logging.cfg
index fcc4ea9..eca5c0e 100644
--- a/karaf/gshell/gshell-admin/src/main/resources/org/apache/felix/karaf/gshell/admin/etc/org.ops4j.pax.logging.cfg
+++ b/karaf/gshell/gshell-admin/src/main/resources/org/apache/felix/karaf/gshell/admin/etc/org.ops4j.pax.logging.cfg
@@ -32,5 +32,5 @@
 log4j.appender.out=org.apache.log4j.FileAppender
 log4j.appender.out.layout=org.apache.log4j.PatternLayout
 log4j.appender.out.layout.ConversionPattern=%d{ABSOLUTE} | %-5.5p | %-16.16t | %-32.32c{1} | %-32.32C %4L | %m%n
-log4j.appender.out.file=${karaf.base}/data/log/servicemix.log
+log4j.appender.out.file=${karaf.base}/data/log/karaf.log
 log4j.appender.out.append=true
diff --git a/karaf/gshell/gshell-core/src/main/filtered-resources/org/apache/felix/karaf/gshell/core/servicemix-version.properties b/karaf/gshell/gshell-core/src/main/filtered-resources/org/apache/felix/karaf/gshell/core/karaf-version.properties
similarity index 100%
rename from karaf/gshell/gshell-core/src/main/filtered-resources/org/apache/felix/karaf/gshell/core/servicemix-version.properties
rename to karaf/gshell/gshell-core/src/main/filtered-resources/org/apache/felix/karaf/gshell/core/karaf-version.properties
diff --git a/karaf/gshell/gshell-core/src/main/java/org/apache/felix/karaf/gshell/core/ApplicationImpl.java b/karaf/gshell/gshell-core/src/main/java/org/apache/felix/karaf/gshell/core/ApplicationImpl.java
index a512d44..4c01969 100644
--- a/karaf/gshell/gshell-core/src/main/java/org/apache/felix/karaf/gshell/core/ApplicationImpl.java
+++ b/karaf/gshell/gshell-core/src/main/java/org/apache/felix/karaf/gshell/core/ApplicationImpl.java
@@ -33,7 +33,7 @@
 public class ApplicationImpl implements Application  {
 
 	private static final String EMBEDDED_PROPS = "org/apache/felix/karaf/version/embedded.properties";
-    private static final String SERVICEMIX_VERSION ="org/apache/felix/karaf/gshell/core/servicemix-version.properties";
+    private static final String SERVICEMIX_VERSION ="org/apache/felix/karaf/gshell/core/karaf-version.properties";
     private static final String VERSION_PROPERTY = "version";
 
     private String id;
diff --git a/karaf/gshell/gshell-core/src/main/java/org/apache/felix/karaf/gshell/core/commands/InfoAction.java b/karaf/gshell/gshell-core/src/main/java/org/apache/felix/karaf/gshell/core/commands/InfoAction.java
index b9ace8d..ba09d82 100644
--- a/karaf/gshell/gshell-core/src/main/java/org/apache/felix/karaf/gshell/core/commands/InfoAction.java
+++ b/karaf/gshell/gshell-core/src/main/java/org/apache/felix/karaf/gshell/core/commands/InfoAction.java
@@ -64,13 +64,13 @@
         io = context.getIo();
 
         //
-        // print ServiceMix informations
+        // print Karaf informations
         //
         maxNameLen = 25;
-        io.out.println("ServiceMix");
-        printValue("ServiceMix home", maxNameLen, System.getProperty("karaf.home"));
-        printValue("ServiceMix base", maxNameLen, System.getProperty("karaf.base"));
-        printValue("ServiceMix Kernel version", maxNameLen, branding.getParent().getVersion());
+        io.out.println("Apache Felix Karaf");
+        printValue("Karaf home", maxNameLen, System.getProperty("karaf.home"));
+        printValue("Karaf base", maxNameLen, System.getProperty("karaf.base"));
+        printValue("Karaf version", maxNameLen, branding.getParent().getVersion());
 
         if (branding.getApplicationName() != null && branding.getApplicationVersion() != null) {
             printValue(branding.getApplicationName() + " version", maxNameLen, branding.getApplicationVersion());
diff --git a/karaf/gshell/gshell-features/src/main/resources/META-INF/spring/gshell-features.xml b/karaf/gshell/gshell-features/src/main/resources/META-INF/spring/gshell-features.xml
index c995a48..2f05dfe 100644
--- a/karaf/gshell/gshell-features/src/main/resources/META-INF/spring/gshell-features.xml
+++ b/karaf/gshell/gshell-features/src/main/resources/META-INF/spring/gshell-features.xml
@@ -105,7 +105,7 @@
 
     <osgi:service ref="featuresService" interface="org.apache.felix.karaf.gshell.features.FeaturesService" />
 
-    <osgix:cm-properties id="cmProps" persistent-id="org.apache.servicemix.features">
+    <osgix:cm-properties id="cmProps" persistent-id="org.apache.felix.karaf.features">
         <prop key="featuresRepositories"></prop>
         <prop key="featuresBoot"></prop>
     </osgix:cm-properties>
diff --git a/karaf/gshell/gshell-osgi/src/main/java/org/apache/felix/karaf/gshell/osgi/Shutdown.java b/karaf/gshell/gshell-osgi/src/main/java/org/apache/felix/karaf/gshell/osgi/Shutdown.java
index 97b4272..f73161a 100644
--- a/karaf/gshell/gshell-osgi/src/main/java/org/apache/felix/karaf/gshell/osgi/Shutdown.java
+++ b/karaf/gshell/gshell-osgi/src/main/java/org/apache/felix/karaf/gshell/osgi/Shutdown.java
@@ -20,7 +20,7 @@
 import org.osgi.framework.Bundle;
 
 /**
- * Command to shut down ServiceMix Kernel
+ * Command to shut down Karaf
  */
 public class Shutdown extends OsgiCommandSupport {
 
@@ -31,7 +31,7 @@
                     Bundle bundle = getBundleContext().getBundle(0);
                     bundle.stop();
                 } catch (Exception e) {
-                    log.error("Error when shutting down ServiceMix Kernel", e);
+                    log.error("Error when shutting down Apache Felix Karaf", e);
                 }
             }
         }.start();
diff --git a/karaf/gshell/gshell-wrapper/src/main/resources/org/apache/felix/karaf/gshell/wrapper/InstallCommand.properties b/karaf/gshell/gshell-wrapper/src/main/resources/org/apache/felix/karaf/gshell/wrapper/InstallCommand.properties
index 785b4d8..f9fccf7 100644
--- a/karaf/gshell/gshell-wrapper/src/main/resources/org/apache/felix/karaf/gshell/wrapper/InstallCommand.properties
+++ b/karaf/gshell/gshell-wrapper/src/main/resources/org/apache/felix/karaf/gshell/wrapper/InstallCommand.properties
@@ -21,7 +21,7 @@
 ## $Rev: 703511 $ $Date: 2008-10-10 18:07:36 +0200 (Fri, 10 Oct 2008) $
 ##
 
-command.description=Install ServiceMix Kernel as a system service in the OS.
+command.description=Install Karaf as a system service in the OS.
 
 command.manual=\
   TODO: install manual
diff --git a/karaf/gshell/gshell-wrapper/src/main/resources/org/apache/felix/karaf/gshell/wrapper/all/servicemix-wrapper.conf b/karaf/gshell/gshell-wrapper/src/main/resources/org/apache/felix/karaf/gshell/wrapper/all/karaf-wrapper.conf
similarity index 90%
rename from karaf/gshell/gshell-wrapper/src/main/resources/org/apache/felix/karaf/gshell/wrapper/all/servicemix-wrapper.conf
rename to karaf/gshell/gshell-wrapper/src/main/resources/org/apache/felix/karaf/gshell/wrapper/all/karaf-wrapper.conf
index 1095fbd..1230daa 100644
--- a/karaf/gshell/gshell-wrapper/src/main/resources/org/apache/felix/karaf/gshell/wrapper/all/servicemix-wrapper.conf
+++ b/karaf/gshell/gshell-wrapper/src/main/resources/org/apache/felix/karaf/gshell/wrapper/all/karaf-wrapper.conf
@@ -18,25 +18,25 @@
 #********************************************************************
 # Wrapper Properties
 #********************************************************************
-set.default.SERVICEMIX_HOME=${servicemix.home}
-set.default.SERVICEMIX_BASE=${servicemix.base}
+set.default.KARAF_HOME=${karaf.home}
+set.default.KARAF_BASE=${karaf.base}
 
 # Java Application
 wrapper.working.dir=%SERVICEMIX_BASE%
 wrapper.java.command=java
 wrapper.java.mainclass=org.tanukisoftware.wrapper.WrapperSimpleApp
-wrapper.java.classpath.1=%SERVICEMIX_BASE%/lib/servicemix-wrapper.jar
-wrapper.java.classpath.2=%SERVICEMIX_HOME%/lib/servicemix.jar
-wrapper.java.classpath.3=%SERVICEMIX_HOME%/lib/servicemix-jaas-boot.jar
-wrapper.java.library.path.1=%SERVICEMIX_BASE%/lib/
+wrapper.java.classpath.1=%KARAF_BASE%/lib/karaf-wrapper.jar
+wrapper.java.classpath.2=%KARAF_HOME%/lib/karaf.jar
+wrapper.java.classpath.3=%KARAF_HOME%/lib/karaf-jaas-boot.jar
+wrapper.java.library.path.1=%KARAF_BASE%/lib/
 
 # Application Parameters.  Add parameters as needed starting from 1
 wrapper.app.parameter.1=org.apache.felix.karaf.main.Main
 
 # JVM Parameters
 # note that n is the parameter number starting from 1.
-wrapper.java.additional.1=-Dservicemix.home=%SERVICEMIX_HOME%
-wrapper.java.additional.2=-Dservicemix.base=%SERVICEMIX_BASE%
+wrapper.java.additional.1=-Dservicemix.home=%KARAF_HOME%
+wrapper.java.additional.2=-Dservicemix.base=%KARAF_BASE%
 wrapper.java.additional.3=-Dcom.sun.management.jmxremote
 wrapper.java.additional.4=-Dservicemix.startLocalConsole=false
 wrapper.java.additional.5=-Dservicemix.startRemoteShell=true
diff --git a/karaf/gshell/gshell-admin/src/main/java/org/apache/felix/karaf/gshell/admin/internal/commands/CreateCommand.java b/karaf/gshell/gshell-admin/src/main/java/org/apache/felix/karaf/gshell/admin/internal/commands/CreateCommand.java
index f255530..2bc1309 100644
--- a/karaf/gshell/gshell-admin/src/main/java/org/apache/felix/karaf/gshell/admin/internal/commands/CreateCommand.java
+++ b/karaf/gshell/gshell-admin/src/main/java/org/apache/felix/karaf/gshell/admin/internal/commands/CreateCommand.java
@@ -20,7 +20,7 @@
 import org.apache.geronimo.gshell.clp.Option;
 
 /**
  * Creates a new servicemix instance 
  *
  * @version $Rev: 679826 $ $Date: 2008-07-25 17:00:12 +0200 (Fri, 25 Jul 2008) $
  */
@@ -32,7 +32,7 @@
     @Option(name = "-l", aliases = { "--location"}, description = "Location of the new instance on the file system")
     private String location;
 
-    @Argument(index=0, required=true, description="Name of the new ServiceMix instance")
+    @Argument(index=0, required=true, description="Name of the new Karaf instance")
     private String instance = null;
 
     protected Object doExecute() throws Exception {
@@ -20,7 +20,7 @@
 
 /**
- * Creates a new servicemix instance 
+ * Creates a new Karaf instance 
  *
  * @version $Rev: 679826 $ $Date: 2008-07-25 17:00:12 +0200 (Fri, 25 Jul 2008) $
diff --git a/karaf/gshell/gshell-wrapper/src/main/java/org/apache/felix/karaf/gshell/wrapper/InstallCommand.java b/karaf/gshell/gshell-wrapper/src/main/java/org/apache/felix/karaf/gshell/wrapper/InstallCommand.java
index 9e4f365..6f3a7e1 100644
--- a/karaf/gshell/gshell-wrapper/src/main/java/org/apache/felix/karaf/gshell/wrapper/InstallCommand.java
+++ b/karaf/gshell/gshell-wrapper/src/main/java/org/apache/felix/karaf/gshell/wrapper/InstallCommand.java
@@ -31,7 +31,7 @@
 import org.apache.felix.karaf.gshell.core.OsgiCommandSupport;
 
 /**
  * Installs this ServiceMix instance as a service in your operating systems. 
  *
  * @version $Rev: 603634 $ $Date: 2007-12-12 16:07:16 +0100 (Wed, 12 Dec 2007) $
  */
@@ -39,7 +39,7 @@
 {
 	
     @Option(name="-n", aliases={"--name"}, description="The service name that will be used when installing the service.")
-    private String name="servicemix";
+    private String name="karaf";
     @Option(name="-d", aliases={"--display"}, description="The display name of the service.")
     private String displayName;
     @Option(name="-D", aliases={"--description"}, description="The description of the service.")
@@ -68,20 +68,20 @@
 			File serviceFile=null;
 			if( os.startsWith("Win") ) {
 				mkdir(bin);
-				copyResourceTo(new File(bin, name+"-wrapper.exe"), "windows/servicemix-wrapper.exe", false);
+				copyResourceTo(new File(bin, name+"-wrapper.exe"), "windows/karaf-wrapper.exe", false);
 				serviceFile = new File(bin,name+"-service.bat");
-				copyFilteredResourceTo(serviceFile, "windows/servicemix-service.bat", props);
+				copyFilteredResourceTo(serviceFile, "windows/karaf-service.bat", props);
 				mkdir(lib);
 				copyResourceTo(new File(bin, "wrapper.dll"), "windows/wrapper.dll", false);								
 			} else if( os.startsWith("Mac OS X") ) {
 				mkdir(bin);
 				
 				File file = new File(bin, name+"-wrapper");
-				copyResourceTo(file, "macosx/servicemix-wrapper", false);
+				copyResourceTo(file, "macosx/karaf-wrapper", false);
 				chmod(file, "a+x");
 				
 				serviceFile = new File(bin,name+"-service");
-				copyFilteredResourceTo(serviceFile, "unix/servicemix-service", props);
+				copyFilteredResourceTo(serviceFile, "unix/karaf-service", props);
 				chmod(serviceFile, "a+x");
 				
 				mkdir(lib);
@@ -93,11 +93,11 @@
 				mkdir(bin);
 				
 				File file = new File(bin, name+"-wrapper");
-				copyResourceTo(file, "linux/servicemix-wrapper", false);
+				copyResourceTo(file, "linux/karaf-wrapper", false);
 				chmod(file, "a+x");
 
 				serviceFile = new File(bin,name+"-service");
-				copyFilteredResourceTo(serviceFile, "unix/servicemix-service", props);
+				copyFilteredResourceTo(serviceFile, "unix/karaf-service", props);
 				chmod(serviceFile, "a+x");
 				
 				mkdir(lib);
@@ -112,10 +112,10 @@
 
     		// Install the wrapper jar to the lib directory..
 			mkdir(lib);
-			copyResourceTo(new File(lib, "servicemix-wrapper.jar"), "all/servicemix-wrapper.jar", false);
+			copyResourceTo(new File(lib, "karaf-wrapper.jar"), "all/karaf-wrapper.jar", false);
 			mkdir(etc);
 			File wrapperConf = new File(etc,name+"-wrapper.conf");
-			copyFilteredResourceTo(wrapperConf, "all/servicemix-wrapper.conf", props);
+			copyFilteredResourceTo(wrapperConf, "all/karaf-wrapper.conf", props);
 
 			io.out.println("");
 			io.out.println("Setup complete.  You may want to tweak the JVM properties in the wrapper configuration file: "+wrapperConf.getPath());
@@ -139,7 +139,7 @@
 				io.out.println("");
 				io.out.println("At this time it is not known how to get this service to start when the machine is rebooted.");
 				io.out.println("If you know how to install the following service script so that it gets started");
-				io.out.println("when OS X starts, please email dev@servicemix.apache.org and let us know how so");
+				io.out.println("when OS X starts, please email dev@felix.apache.org and let us know how so");
 				io.out.println("we can update this message.");
 				io.out.println(" ");
 				io.out.println("  To start the service:");
@@ -31,7 +31,7 @@
 
 /**
- * Installs this ServiceMix instance as a service in your operating systems. 
+ * Installs this Karaf instance as a service in your operating systems.
  *
  * @version $Rev: 603634 $ $Date: 2007-12-12 16:07:16 +0100 (Wed, 12 Dec 2007) $
diff --git a/karaf/gshell/gshell-wrapper/src/main/resources/org/apache/felix/karaf/gshell/wrapper/all/servicemix-wrapper.jar b/karaf/gshell/gshell-wrapper/src/main/resources/org/apache/felix/karaf/gshell/wrapper/all/karaf-wrapper.jar
similarity index 100%
rename from karaf/gshell/gshell-wrapper/src/main/resources/org/apache/felix/karaf/gshell/wrapper/all/servicemix-wrapper.jar
rename to karaf/gshell/gshell-wrapper/src/main/resources/org/apache/felix/karaf/gshell/wrapper/all/karaf-wrapper.jar
Binary files differ
diff --git a/karaf/gshell/gshell-wrapper/src/main/resources/org/apache/felix/karaf/gshell/wrapper/linux/servicemix-wrapper b/karaf/gshell/gshell-wrapper/src/main/resources/org/apache/felix/karaf/gshell/wrapper/linux/karaf-wrapper
similarity index 100%
rename from karaf/gshell/gshell-wrapper/src/main/resources/org/apache/felix/karaf/gshell/wrapper/linux/servicemix-wrapper
rename to karaf/gshell/gshell-wrapper/src/main/resources/org/apache/felix/karaf/gshell/wrapper/linux/karaf-wrapper
Binary files differ
diff --git a/karaf/gshell/gshell-wrapper/src/main/resources/org/apache/felix/karaf/gshell/wrapper/macosx/servicemix-wrapper b/karaf/gshell/gshell-wrapper/src/main/resources/org/apache/felix/karaf/gshell/wrapper/macosx/karaf-wrapper
similarity index 100%
rename from karaf/gshell/gshell-wrapper/src/main/resources/org/apache/felix/karaf/gshell/wrapper/macosx/servicemix-wrapper
rename to karaf/gshell/gshell-wrapper/src/main/resources/org/apache/felix/karaf/gshell/wrapper/macosx/karaf-wrapper
Binary files differ